<!DOCTYPE html>
<html data-theme="light">
  <head>
    <title>
      {% block title %}{% endblock %}
    </title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />
    {% load static %}
    <link rel="stylesheet" href="{% static 'pico.blue.min.css' %}">
    <link rel="stylesheet" href="{% static 'pico.colors.min.css' %}">
    <link rel="stylesheet" href="{% static 'custom.css' %}">
    <script src="{% static 'htmx.min.js' %}" defer></script>
    {% block extra_media %}{% endblock %}
  </head>
  <body hx-headers='{"X-CSRFToken": "{{ csrf_token }}"}'>
    {% block content_wrapper %}
      <main class="container">
        {% block content %}{% endblock %}
      </main>
    {% endblock %}
  </body>
</html>
