# Generated by Django 5.0.4 on 2024-04-21 17:44

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("api", "0004_project_rstudio_version"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="project",
            name="url",
        ),
        migrations.AddField(
            model_name="project",
            name="local_url",
            field=models.URLField(
                default="",
                help_text="Local URL to access the project's RStudio instance",
                max_length=1024,
            ),
        ),
        migrations.AddField(
            model_name="project",
            name="tailscale_funnel_url",
            field=models.URLField(
                default="",
                help_text="Tailscale Funnel URL to access the project's RStudio instance from the web",
                max_length=1024,
            ),
        ),
        migrations.AddField(
            model_name="project",
            name="tailscale_serve_url",
            field=models.URLField(
                default="",
                help_text="Tailscale Serve URL to access the project's RStudio instance from the tailnet",
                max_length=1024,
            ),
        ),
    ]
