# Generated by Django 5.0.4 on 2024-07-01 08:28

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('api', '0020_alter_container_port'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='container',
            name='tailscale_funnel_url',
        ),
        migrations.RemoveField(
            model_name='container',
            name='tailscale_serve_url',
        ),
    ]
