# Generated by Django 5.0.4 on 2024-04-20 17:39

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("api", "0002_project_is_active"),
    ]

    operations = [
        migrations.AddField(
            model_name="project",
            name="url",
            field=models.URLField(
                default="http://localhost:8387",
                help_text="URL to access the project's RStudio instance",
                max_length=1024,
            ),
            preserve_default=False,
        ),
    ]
